@@ -1,4 +1,4 @@
-__version__ = "0.6.12"
+__version__ = "0.6.13"
 
 from .core import (
     magicclass,
@@ -23,6 +23,7 @@ from .wrappers import (
     impl_preview,
     mark_on_calling,
     mark_on_called,
+    abstractapi,
 )
 
 from .fields import (
@@ -61,6 +62,7 @@ __all__ = [
     "impl_preview",
     "mark_on_calling",
     "mark_on_called",
+    "abstractapi",
     "field",
     "vfield",
     "widget_property",
@@ -108,7 +110,7 @@ def __getattr__(key: str):
             DeprecationWarning,
             stacklevel=2,
         )
-        from .functools import wraps
+        from magicclass.functools import wraps
 
         return wraps
 
