@@ -16,7 +16,6 @@ from typing_extensions import _AnnotatedAlias, Literal
 import inspect
 import warnings
 from enum import Enum
-from docstring_parser import parse, compose
 from qtpy.QtWidgets import QWidget, QDockWidget
 
 from psygnal import Signal
@@ -33,8 +32,13 @@ from magicgui.widgets import (
     MainWindow,
 )
 from magicgui.application import use_app
-from magicgui.widgets._bases.widget import Widget
-from magicgui.widgets._bases import ButtonWidget
+from magicclass._magicgui_compat import (
+    ButtonWidget,
+    WidgetProtocol,
+    Undefined,
+    MGUI_SIMPLE_TYPES,
+    ValueWidget,
+)
 from macrokit import Symbol
 
 from .keybinding import as_shortcut
@@ -51,9 +55,8 @@ from ._macro import GuiMacro
 from ._macro_utils import inject_recorder, value_widget_callback
 from ._icon import get_icon
 
-from ..utils import (
+from magicclass.utils import (
     get_signature,
-    iter_members,
     Tooltips,
     move_to_screen_center,
     argcount,
@@ -61,16 +64,16 @@ from ..utils import (
     method_as_getter,
     eval_attribute,
 )
-from ..widgets import Separator, FreeWidget
-from ..fields import MagicField
-from ..signature import (
+from magicclass.widgets import Separator, FreeWidget
+from magicclass.fields import MagicField, MagicValueField, field, vfield
+from magicclass.signature import (
     MagicMethodSignature,
     get_additional_option,
     split_annotated_type,
 )
-from ..wrappers import upgrade_signature
-from ..types import BoundLiteral
-from ..functools import wraps
+from magicclass.wrappers import upgrade_signature, abstractapi
+from magicclass.types import BoundLiteral
+from magicclass.functools import wraps
 
 if TYPE_CHECKING:
     import numpy as np
@@ -78,6 +81,9 @@ if TYPE_CHECKING:
     from types import TracebackType
     from typing_extensions import Self
 
+    _X = TypeVar("_X", bound=MGUI_SIMPLE_TYPES)
+    _M = TypeVar("_M", bound="MagicTemplate")
+
 
 class PopUpMode(Enum):
     """Define how to popup FunctionGui."""
@@ -152,7 +158,8 @@ defaults = {
     "popup_mode": PopUpMode.popup,
     "error_mode": ErrorMode.msgbox,
     "close_on_run": True,
-    "macro-max-history": 1000,
+    "macro-max-history": 100000,
+    "macro-highlight": False,
 }
 
 _RESERVED = frozenset(
@@ -239,7 +246,7 @@ class _MagicTemplateMeta(ABCMeta):
         return self
 
 
-_W = TypeVar("_W")
+_W = TypeVar("_W", bound=Widget)
 
 
 class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
@@ -301,11 +308,13 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
     def __getitem__(self, key):
         raise NotImplementedError()
 
-    def index(self, value: Any, start: int, stop: int) -> int:
-        raise NotImplementedError()
+    if TYPE_CHECKING:
 
-    def remove(self, value: Widget | str):
-        raise NotImplementedError()
+        def index(self, value: Any, start: int, stop: int) -> int:
+            raise NotImplementedError()
+
+        def remove(self, value: Widget | str):
+            raise NotImplementedError()
 
     def _fast_insert(self, key: int, widget: _W | Callable) -> None:
         raise NotImplementedError()
@@ -489,6 +498,10 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                     )
                 upgrade_signature(predefined, additional_options={"copyto": []})
 
+                # if abstractapi, mark as resolved
+                if isinstance(predefined, abstractapi):
+                    predefined.resolve()
+
             if copy:
                 copyto_list = get_additional_option(func, "copyto", [])
                 copyto_list.append(cls.__name__)
@@ -502,7 +515,7 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
     def _unwrap_method(
         self,
         method_name: str,
-        widget: FunctionGui | PushButtonPlus | Action,
+        widget: FunctionGui | PushButtonPlus | AbstractAction,
         moveto: str,
         copyto: list[str],
     ):
@@ -546,20 +559,21 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                     index = n_children
                     new = True
 
-                self._fast_insert(len(self), widget)
+                self._fast_insert(len(self), widget, remove_label=True)
                 copy = _name in copyto
 
-                if isinstance(widget, FunctionGui):
+                if not isinstance(widget, (PushButtonPlus, AbstractAction)):
                     if copy:
                         widget = widget.copy()
                     if new:
                         child_instance._fast_insert(n_children, widget)
                     else:
-                        del child_instance[index - 1]
+                        del child_instance[index]
                         child_instance._fast_insert(index, widget)
-                    widget.visible = True
 
                 else:
+                    # NOTE: wrapping button with action is not supported in the
+                    # method above.
                     widget.visible = copy
                     if new:
                         child_widget = child_instance._create_widget_from_method(
@@ -586,6 +600,135 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                 f"{method_name} not found in class {self.__class__.__name__}"
             )
 
+    # fmt: off
+    @overload
+    @classmethod
+    def field(cls, type_of_widget: type[_W], *, name: str | None = None, label: str | None = None, options: dict[str, Any] = {}, record: bool = True) -> MagicField[_W, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, obj: type[_X], *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicField[ValueWidget, _X]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, obj: _X, *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True) -> MagicField[ValueWidget, _X]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, gui_class: type[_M], *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicField[_M, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, obj: Any, *, name: str | None = None, label: str | None = None, widget_type: type[_W] = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicField[_W, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, obj: Any, *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicField[Widget, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def field(cls, *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicField[Widget, Any]: ...  # noqa
+    # fmt: on
+
+    @classmethod
+    def field(
+        cls,
+        obj=Undefined,
+        *,
+        name=None,
+        label=None,
+        widget_type=None,
+        options={},
+        record=True,
+    ) -> MagicField:
+        """
+        Make a MagicField object, with the widget in the child class.
+
+        >>> @magicclass
+        ... class A:
+        ...     @magicclass
+        ...     class B:
+        ...         i = ...  # pre-definition
+        ...     i = B.field(1)
+
+        Parameters
+        ----------
+        obj : Any, default is Undefined
+            Reference to determine what type of widget will be created. If Widget
+            subclass is given, it will be used as is. If other type of class is given,
+            it will used as type annotation. If an object (not type) is given, it will
+            be assumed to be the default value.
+        name : str, optional
+            Name of the widget.
+        label : str, optional
+            Label of the widget.
+        widget_type : str, optional
+            Widget type. This argument will be sent to ``create_widget`` function.
+        options : dict, optional
+            Widget options. This parameter will be passed to the ``options`` keyword
+            argument of ``create_widget``.
+        record : bool, default is True
+            A magic-class specific parameter. If true, record value changes as macro.
+
+        Returns
+        -------
+        MagicField
+        """
+        fld = field(
+            obj,
+            name=name,
+            label=label,
+            widget_type=widget_type,
+            options=options,
+            record=record,
+        )
+        fld.set_destination(cls)
+        return fld
+
+    # fmt: off
+    @overload
+    @classmethod
+    def vfield(cls, widget_type: type[_W], *, name: str | None = None, label: str | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicValueField[_W, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def vfield(cls, obj: _X, *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicValueField[ValueWidget, _X]: ...  # noqa
+
+    @overload
+    @classmethod
+    def vfield(cls, annotation: type[_X], *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicValueField[ValueWidget, _X]: ...  # noqa
+
+    @overload
+    @classmethod
+    def vfield(cls, obj: Any, *, name: str | None = None, label: str | None = None, widget_type: type[_W] = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicValueField[_W, Any]: ...  # noqa
+
+    @overload
+    @classmethod
+    def vfield(cls, obj: Any, *, name: str | None = None, label: str | None = None, widget_type: str | type[WidgetProtocol] | type[Widget] | None = None, options: dict[str, Any] = {}, record: bool = True, ) -> MagicValueField[Widget, Any]: ...  # noqa
+    # fmt: on
+
+    @classmethod
+    def vfield(
+        cls,
+        obj=Undefined,
+        *,
+        name=None,
+        label=None,
+        widget_type=None,
+        options={},
+        record=True,
+    ) -> MagicValueField:
+        fld = vfield(
+            obj,
+            name=name,
+            label=label,
+            widget_type=widget_type,
+            options=options,
+            record=record,
+        )
+        fld.set_destination(cls)
+        return fld
+
     def _convert_attributes_into_widgets(self):
         """
         This function is called in dynamically created __init__. Methods, fields and nested
@@ -608,6 +751,9 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
 
     def _create_widget_from_method(self, obj: MethodType):
         """Convert instance methods into GUI objects, such as push buttons or actions."""
+        if isinstance(obj, abstractapi):
+            obj.check_resolved()
+
         if hasattr(obj, "__name__"):
             obj_name = obj.__name__
         else:
@@ -668,24 +814,26 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
 
             def run_function():
                 mgui = _build_mgui(widget, func, self)
+                _need_title_bar = self._popup_mode not in (
+                    PopUpMode.popup,
+                    PopUpMode.dock,
+                    PopUpMode.parentsub,
+                    PopUpMode.dialog,
+                )
                 if mgui.call_count == 0:  # connect only once
                     _prep_func(mgui)
-                    if self._popup_mode not in (
-                        PopUpMode.popup,
-                        PopUpMode.dock,
-                        PopUpMode.parentsub,
-                        PopUpMode.dialog,
-                    ):
+                    if _need_title_bar:
                         mgui.label = ""
                         # to avoid name collision
                         mgui.name = f"mgui-{id(mgui._function)}"
                         mgui.margins = (0, 0, 0, 0)
-                        title = Separator(
-                            orientation="horizontal", title=text, button=True
-                        )
-                        # TODO: should remove mgui from self?
-                        title.btn_clicked.connect(mgui.hide)
-                        mgui.insert(0, title)
+                        if not isinstance(mgui[0], Separator):
+                            title = Separator(
+                                orientation="horizontal", title=text, button=True
+                            )
+                            # TODO: should remove mgui from self?
+                            title.btn_clicked.connect(mgui.hide)
+                            mgui.insert(0, title)
 
                     if self._close_on_run and not mgui._auto_call:
                         if self._popup_mode not in (
@@ -700,7 +848,7 @@ class MagicTemplate(MutableSequence[_W], metaclass=_MagicTemplateMeta):
                             mgui.called.connect(lambda: mgui.parent.hide())
 
                 if nparams == 1 and issubclass(fgui_classes[0], FileEdit):
-                    fdialog: FileEdit = mgui[0]
+                    fdialog: FileEdit = mgui[int(_need_title_bar)]
                     if result := fdialog._show_file_dialog(
                         fdialog.mode,
                         caption=fdialog._btn_text,
@@ -1110,7 +1258,15 @@ def convert_attributes(cls: type[_T], hide: tuple[type, ...]) -> dict[str, Any]:
         New namespace.
     """
     _dict: dict[str, Callable] = {}
-    _pass_type = (property, classmethod, staticmethod, type, Widget, MagicField)
+    _pass_type = (
+        property,
+        classmethod,
+        staticmethod,
+        type,
+        Widget,
+        MagicField,
+        abstractapi,
+    )
     mro = [c for c in cls.__mro__ if c not in hide]
     for subcls in reversed(mro):
         for name, obj in subcls.__dict__.items():
