@@ -3,11 +3,26 @@ from typing import Any, Callable, Sequence, TypeVar
 import warnings
 from qtpy.QtWidgets import QMenuBar, QWidget, QMainWindow, QBoxLayout, QDockWidget
 from qtpy.QtCore import Qt
-from magicgui.widgets import Container, MainWindow, Label, FunctionGui, Image, Table
-from magicgui.widgets._bases import Widget, ButtonWidget, ValueWidget, ContainerWidget
-from magicgui.widgets._concrete import _LabeledWidget, ContainerWidget
+from magicgui.widgets import (
+    Container,
+    MainWindow,
+    Label,
+    FunctionGui,
+    Image,
+    Table,
+    Widget,
+)
+from magicclass._magicgui_compat import (
+    ButtonWidget,
+    ValueWidget,
+    ContainerWidget,
+    _LabeledWidget,
+    ContainerWidget,
+)
 from macrokit import Symbol
 
+from magicclass.wrappers import abstractapi
+
 
 from .keybinding import register_shortcut
 from .mgui_ext import PushButtonPlus
@@ -20,7 +35,7 @@ from ._base import (
 )
 from .utils import format_error, connect_magicclasses
 from ._macro_utils import value_widget_callback, nested_function_gui_callback
-from ..widgets import (
+from magicclass.widgets import (
     ButtonContainer,
     GroupBoxContainer,
     FrameContainer,
@@ -37,10 +52,10 @@ from ..widgets import (
     FreeWidget,
 )
 
-from ..utils import iter_members, Tooltips
-from ..fields import MagicField
-from ..signature import get_additional_option
-from .._app import run_app
+from magicclass.utils import iter_members, Tooltips
+from magicclass.fields import MagicField
+from magicclass.signature import get_additional_option
+from magicclass._app import run_app
 
 # For Containers that belong to these classes, menubar must be set to _qwidget.layout().
 _USE_OUTER_LAYOUT = (
@@ -113,6 +128,7 @@ class ClassGuiBase(BaseGui[Widget]):
         _hist: list[tuple[str, str, str]] = []  # for traceback
         _annot = ClassGuiBase.__annotations__.keys()
         _ignore_types = (property, classmethod, staticmethod)
+
         for name, attr in filter(lambda x: x[0] not in base_members, iter_members(cls)):
             if name in _annot or isinstance(attr, _ignore_types):
                 continue
@@ -262,10 +278,6 @@ class ClassGuiBase(BaseGui[Widget]):
                         self._fast_insert(n_insert, widget)
                         n_insert += 1
 
-                        # NOTE: Function GUI is invisible by some reason...
-                        # See https://github.com/hanjinliu/magic-class/issues/53
-                        widget.visible = True
-
                     _hist.append((name, str(type(attr)), type(widget).__name__))
 
             except Exception as e:
@@ -274,7 +286,9 @@ class ClassGuiBase(BaseGui[Widget]):
         self._unify_label_widths()
         return None
 
-    def _fast_insert(self, key: int, obj: Widget | Callable) -> None:
+    def _fast_insert(
+        self, key: int, obj: Widget | Callable, remove_label: bool = False
+    ) -> None:
         if isinstance(obj, Callable):
             # Sometimes users want to dynamically add new functions to GUI.
             if isinstance(obj, FunctionGui):
@@ -330,7 +344,7 @@ class ClassGuiBase(BaseGui[Widget]):
 
         if self.labels:
             # no labels for button widgets (push buttons, checkboxes, have their own)
-            if not isinstance(widget, _hide_labels):
+            if not isinstance(widget, _hide_labels) and not remove_label:
                 _widget = _LabeledWidget(widget)
                 widget.label_changed.connect(self._unify_label_widths)
 
@@ -338,6 +352,11 @@ class ClassGuiBase(BaseGui[Widget]):
             key += len(self)
         self._list.insert(key, widget)
         self._widget._mgui_insert_widget(key, _widget)
+
+        # NOTE: Function GUI is invisible by some reason...
+        # See https://github.com/hanjinliu/magic-class/issues/53
+        if isinstance(widget, FunctionGui):
+            widget.visible = True
         return None
 
 
