@@ -1,13 +1,14 @@
 from __future__ import annotations
 from typing import Callable
 import warnings
-from magicgui.widgets import Image, Table, Label, FunctionGui
-from magicgui.widgets._bases import ButtonWidget
-from magicgui.widgets._bases.widget import Widget
+from magicgui.widgets import Image, Table, Label, FunctionGui, Widget
+from magicclass._magicgui_compat import ButtonWidget
 from macrokit import Symbol
 from qtpy.QtWidgets import QMenu
 from qtpy.QtCore import Qt
 
+from magicclass.wrappers import abstractapi
+
 from .mgui_ext import AbstractAction, WidgetAction, _LabeledWidgetAction
 from .keybinding import register_shortcut
 from ._base import (
@@ -19,10 +20,10 @@ from ._base import (
 from .utils import format_error, connect_magicclasses
 from ._macro_utils import nested_function_gui_callback, inject_recorder
 
-from ..signature import get_additional_option
-from ..fields import MagicField
-from ..widgets import Separator, FreeWidget
-from ..utils import iter_members, Tooltips
+from magicclass.signature import get_additional_option
+from magicclass.fields import MagicField
+from magicclass.widgets import Separator, FreeWidget
+from magicclass.utils import iter_members, Tooltips
 
 
 def _check_popupmode(popup_mode: PopUpMode):
@@ -59,18 +60,23 @@ class MenuGuiBase(ContainerLikeGui):
             close_on_run=close_on_run, popup_mode=popup_mode, error_mode=error_mode
         )
         name = name or self.__class__.__name__
-        self.native = QMenu(name, parent)
+        self._native = QMenu(name, parent)
         self.native.setToolTipsVisible(True)
         self.name = name
         self._list: list[MenuGuiBase | AbstractAction] = []
         self.labels = labels
 
+    @property
+    def native(self):
+        """The native Qt widget."""
+        return self._native
+
     def _convert_attributes_into_widgets(self):
         cls = self.__class__
 
         # Add class docstring as tooltip.
         _tooltips = Tooltips(cls)
-        self.native.setToolTip(_tooltips.desc)
+        self.tooltip = _tooltips.desc
 
         # Bind all the methods and annotations
         base_members = {x[0] for x in iter_members(MenuGuiBase)}
@@ -159,7 +165,10 @@ class MenuGuiBase(ContainerLikeGui):
         return None
 
     def _fast_insert(
-        self, key: int, obj: Callable | MenuGuiBase | AbstractAction
+        self,
+        key: int,
+        obj: Callable | MenuGuiBase | AbstractAction,
+        remove_label: bool = False,
     ) -> None:
         if isinstance(obj, Callable):
             # Sometimes users want to dynamically add new functions to GUI.
@@ -207,8 +216,9 @@ class MenuGuiBase(ContainerLikeGui):
                     Table,
                 )
                 _obj_labeled = _obj
-                if (not isinstance(_obj.widget, _hide_labels)) and self.labels:
-                    _obj_labeled = _LabeledWidgetAction.from_action(_obj)
+                if self.labels:
+                    if not isinstance(_obj.widget, _hide_labels) and not remove_label:
+                        _obj_labeled = _LabeledWidgetAction.from_action(_obj)
                 _obj_labeled.parent = self
                 insert_action_like(self.native, key, _obj_labeled.native)
 
