@@ -11,28 +11,28 @@ from vispy.visuals import (
     MarkersVisual,
     ArrowVisual,
 )
-from vispy.visuals import transforms as tr
 from vispy.visuals.filters import WireframeFilter
 from ._base import LayerItem
 
 from magicgui.widgets import FloatSlider
-from ...widgets import FloatRangeSlider
-from ...fields import HasFields, vfield
-from ...types import Color
+from magicclass.widgets import FloatRangeSlider
+from magicclass.fields import HasFields, vfield
+from magicclass.types import Color
 
 # Copied from napari/_vispy/utils/gl.py
 BLENDING_MODES = {
-    'opaque': dict(preset='opaque'),
-    'translucent': dict(preset='translucent'),
-    'translucent_no_depth': dict(
+    "opaque": dict(preset="opaque"),
+    "translucent": dict(preset="translucent"),
+    "translucent_no_depth": dict(
         depth_test=False,
         cull_face=False,
         blend=True,
-        blend_func=('src_alpha', 'one_minus_src_alpha', 'zero', 'one'),
+        blend_func=("src_alpha", "one_minus_src_alpha", "zero", "one"),
     ),
-    'additive': dict(preset='additive'),
+    "additive": dict(preset="additive"),
 }
 
+
 class Image(LayerItem, HasFields):
     RENDERINGS = [
         "translucent",
@@ -471,7 +471,7 @@ class Curve3D(LayerItem, HasFields):
     @width.connect
     def _on_width_change(self, value):
         return self._visual.set_data(width=value)
-    
+
     @blending.connect
     def _on_blending_change(self, value):
         blending_kwargs = BLENDING_MODES[value]
@@ -499,7 +499,7 @@ class Points3D(LayerItem, HasFields):
         self._visual: MarkersVisual = visuals.Markers(
             scaling=True, parent=self._viewbox.scene, spherical=True
         )
-        self.data = data[:, ::-1]
+        self.data = data
         self.face_color = face_color
         self.edge_color = edge_color
         self.edge_width = edge_width
@@ -509,20 +509,19 @@ class Points3D(LayerItem, HasFields):
 
     @property
     def data(self) -> np.ndarray:
-        return self._data
+        return self._data[:, ::-1]
 
     @data.setter
     def data(self, value) -> None:
+        _value = value[:, ::-1]
         self._visual.set_data(
-            pos=value,
+            pos=_value,
             face_color=self.face_color,
             edge_color=self.edge_color,
             edge_width=self.edge_width,
             size=self.size,
-            scaling=True,
-            symbol=self._visual.symbol,
         )
-        self._data = value
+        self._data = _value
         self._visual.update()
 
     # fmt: off
@@ -537,37 +536,31 @@ class Points3D(LayerItem, HasFields):
     @face_color.connect
     def _on_face_color_change(self, value):
         return self._visual.set_data(
-            pos=self.data,
+            pos=self._data,
             face_color=value,
             edge_color=self.edge_color,
             edge_width=self.edge_width,
             size=self.size,
-            scaling=True,
-            symbol=self._visual.symbol,
         )
 
     @edge_color.connect
     def _on_edge_color_change(self, value):
         return self._visual.set_data(
-            pos=self.data,
+            pos=self._data,
             face_color=self.face_color,
             edge_color=value,
             edge_width=self.edge_width,
             size=self.size,
-            scaling=True,
-            symbol=self._visual.symbol,
         )
 
     @edge_width.connect
     def _on_edge_width_change(self, value):
         return self._visual.set_data(
-            pos=self.data,
+            pos=self._data,
             face_color=self.face_color,
             edge_color=self.edge_color,
             edge_width=value,
             size=self.size,
-            scaling=True,
-            symbol=self._visual.symbol,
         )
 
     @spherical.connect
@@ -578,15 +571,13 @@ class Points3D(LayerItem, HasFields):
     @size.connect
     def _on_size_change(self, value):
         return self._visual.set_data(
-            pos=self.data,
+            pos=self._data,
             face_color=self.face_color,
             edge_color=self.edge_color,
             edge_width=self.edge_width,
             size=value,
-            scaling=True,
-            symbol=self._visual.symbol,
         )
-    
+
     @blending.connect
     def _on_blending_change(self, value):
         blending_kwargs = BLENDING_MODES[value]
@@ -595,8 +586,8 @@ class Points3D(LayerItem, HasFields):
         return None
 
     def _get_bbox(self) -> Tuple[np.ndarray, np.ndarray]:
-        mins = np.min(self.data, axis=0)
-        maxs = np.max(self.data, axis=0)
+        mins = np.min(self._data, axis=0)
+        maxs = np.max(self._data, axis=0)
         return mins, maxs
 
 
