@@ -3,36 +3,40 @@ from typing import (
     Any,
     TYPE_CHECKING,
     Callable,
+    Sequence,
     TypeVar,
     overload,
     Generic,
-    Union,
 )
 from typing_extensions import Literal, _AnnotatedAlias
-from pathlib import Path
-import datetime
 import sys
-from enum import Enum
-from magicgui.widgets import create_widget
-from magicgui.widgets._bases import Widget, ValueWidget, ContainerWidget
-from magicgui.widgets._bases.value_widget import UNSET
+from magicgui.widgets import create_widget, Widget
+from magicclass._magicgui_compat import (
+    ValueWidget,
+    ContainerWidget,
+    CategoricalWidget,
+    Undefined,
+    MGUI_SIMPLE_TYPES,
+)
 
 from ._define import define_callback, define_callback_gui
 
-from ..utils import (
+from magicclass.utils import (
     is_instance_method,
     method_as_getter,
     eval_attribute,
 )
-from .._gui.mgui_ext import Action, WidgetAction
+from magicclass.signature import MagicMethodSignature
+from magicclass._gui.mgui_ext import Action, WidgetAction
 
 if TYPE_CHECKING:
-    from magicgui.widgets._protocols import WidgetProtocol
+    from magicclass._magicgui_compat import WidgetProtocol
     from typing_extensions import Self
-    from .._gui._base import MagicTemplate
-    from .._gui.mgui_ext import AbstractAction
+    from magicclass._gui._base import MagicTemplate
+    from magicclass._gui.mgui_ext import AbstractAction
 
     _M = TypeVar("_M", bound=MagicTemplate)
+    _X = TypeVar("_X", bound=MGUI_SIMPLE_TYPES)
 
 if sys.version_info >= (3, 10):
     from typing import _BaseGenericAlias
@@ -49,7 +53,8 @@ class _FieldObject:
 
 
 _W = TypeVar("_W", bound=Widget)
-_V = TypeVar("_V", bound=object)
+_V = TypeVar("_V")
+_U = TypeVar("_U")
 
 
 class MagicField(_FieldObject, Generic[_W, _V]):
@@ -64,7 +69,7 @@ class MagicField(_FieldObject, Generic[_W, _V]):
 
     def __init__(
         self,
-        value: Any = UNSET,
+        value: Any = Undefined,
         name: str | None = None,
         label: str | None = None,
         annotation: Any = None,
@@ -75,8 +80,8 @@ class MagicField(_FieldObject, Generic[_W, _V]):
     ):
         if options is None:
             options = {}
-        if value is UNSET:
-            value = options.pop("value", UNSET)
+        if value is Undefined:
+            value = options.pop("value", Undefined)
 
         if constructor is None:
 
@@ -107,6 +112,9 @@ class MagicField(_FieldObject, Generic[_W, _V]):
         # that it can "know" the namespace it belongs to.
         self._parent_class: type | None = None
 
+        # This attribute will be used when wrapped field/vfield is used.
+        self._destination_class: type | None = None
+
     def __repr__(self):
         attrs = ["value", "name", "widget_type", "record", "options"]
         kw = ", ".join(f"{a}={getattr(self, a)!r}" for a in attrs)
@@ -117,6 +125,90 @@ class MagicField(_FieldObject, Generic[_W, _V]):
         if self.name is None:
             self.name = name
 
+        if self._destination_class is not None:
+            from magicclass.wrappers import abstractapi
+
+            api = getattr(self._destination_class, name, None)
+            if isinstance(api, abstractapi):
+                api.resolve()
+                api.__signature__ = MagicMethodSignature([])
+
+    def set_destination(self, dest: type) -> None:
+        self._destination_class = dest
+        return None
+
+    def with_options(
+        self,
+        value: _V = Undefined,
+        tooltip: str = Undefined,
+        visible: bool = Undefined,
+        enabled: bool = Undefined,
+        gui_only: bool = Undefined,
+        bind=Undefined,
+        **kwargs,
+    ) -> Self:
+        """
+        Method ot add options to the field.
+
+        Following expressions returns the same field.
+        >>> x = field(int, options={"max": 10})
+        >>> x = field(int).with_options(max=10)
+        """
+        kwargs = dict(
+            value=value,
+            tooltip=tooltip,
+            visible=visible,
+            enabled=enabled,
+            gui_only=gui_only,
+            bind=bind,
+            **kwargs,
+        )
+        to_pop: list[str] = []
+        for k, v in kwargs.items():
+            if v is Undefined:
+                to_pop.append(k)
+        for k in to_pop:
+            kwargs.pop(k)
+        if "value" in kwargs:
+            self.value = kwargs.pop("value")
+        self.options.update(kwargs)
+        return self
+
+    @overload
+    def with_choices(
+        self, choices: Sequence[tuple[str, _U]]
+    ) -> MagicField[CategoricalWidget, _U]:
+        ...
+
+    @overload
+    def with_choices(self, choices: Sequence[_U]) -> MagicField[CategoricalWidget, _U]:
+        ...
+
+    @overload
+    def with_choices(
+        self, choices: Callable[..., Sequence[tuple[str, _U]]]
+    ) -> MagicField[CategoricalWidget, _U]:
+        ...
+
+    @overload
+    def with_choices(
+        self, choices: Callable[..., Sequence[_U]]
+    ) -> MagicField[CategoricalWidget, _U]:
+        ...
+
+    def with_choices(self, choices):
+        """Method to add choices to the field."""
+        self.options["choices"] = choices
+        return self
+
+    @property
+    def __signature__(self):
+        """This property is necessary to hack _unwrap_method."""
+        additional_options = {}
+        if self._destination_class is not None:
+            additional_options["into"] = self._destination_class.__name__
+        return MagicMethodSignature([], additional_options=additional_options)
+
     @property
     def constructor(self) -> Callable[..., Widget]:
         """Get widget constructor."""
@@ -212,7 +304,7 @@ class MagicField(_FieldObject, Generic[_W, _V]):
             if type(self.value) is bool or self.annotation is bool:
                 # we should not use "isinstance" or "issubclass" because subclass
                 # may be mapped to different widget by users.
-                value = False if self.value is UNSET else self.value
+                value = False if self.value is Undefined else self.value
                 action = Action(
                     checkable=True,
                     checked=value,
@@ -299,7 +391,7 @@ class MagicField(_FieldObject, Generic[_W, _V]):
 
     def not_ready(self) -> bool:
         return (
-            self.value is UNSET
+            self.value is Undefined
             and self.annotation is None
             and self.widget_type is None
             and "choices" not in self.options
@@ -521,44 +613,51 @@ class MagicValueField(MagicField[_W, _V]):
     def _presethook(self, obj, value):
         return value
 
+    @overload
+    def with_choices(
+        self, choices: Sequence[tuple[str, _U]]
+    ) -> MagicValueField[CategoricalWidget, _U]:
+        ...
 
-# magicgui symple types
-_X = TypeVar(
-    "_X",
-    bound=Union[
-        int,
-        float,
-        bool,
-        str,
-        Path,
-        datetime.datetime,
-        datetime.date,
-        datetime.time,
-        Enum,
-        range,
-        slice,
-        list,
-        tuple,
-    ],
-)
+    @overload
+    def with_choices(
+        self, choices: Sequence[_U]
+    ) -> MagicValueField[CategoricalWidget, _U]:
+        ...
+
+    @overload
+    def with_choices(
+        self, choices: Callable[..., Sequence[tuple[str, _U]]]
+    ) -> MagicValueField[CategoricalWidget, _U]:
+        ...
+
+    @overload
+    def with_choices(
+        self, choices: Callable[..., Sequence[_U]]
+    ) -> MagicValueField[CategoricalWidget, _U]:
+        ...
+
+    def with_choices(self, choices):
+        """Method to add choices to the field."""
+        return super().with_choices(choices)
 
 
 @overload
 def field(
-    obj: _X,
+    gui_class: type[_M],
     *,
     name: str | None = None,
     label: str | None = None,
     widget_type: str | type[WidgetProtocol] | type[Widget] | None = None,
     options: dict[str, Any] = {},
     record: bool = True,
-) -> MagicField[ValueWidget, _X]:
+) -> MagicField[_M, Any]:
     ...
 
 
 @overload
 def field(
-    widget_type: type[_W],
+    type_of_widget: type[_W],
     *,
     name: str | None = None,
     label: str | None = None,
@@ -583,14 +682,14 @@ def field(
 
 @overload
 def field(
-    gui_class: type[_M],
+    obj: _X,
     *,
     name: str | None = None,
     label: str | None = None,
     widget_type: str | type[WidgetProtocol] | type[Widget] | None = None,
     options: dict[str, Any] = {},
     record: bool = True,
-) -> MagicField[_M, Any]:
+) -> MagicField[ValueWidget, _X]:
     ...
 
 
@@ -620,15 +719,27 @@ def field(
     ...
 
 
+@overload
 def field(
-    obj: Any = UNSET,
     *,
     name: str | None = None,
     label: str | None = None,
-    widget_type: str | type[WidgetProtocol] | None = None,
+    widget_type: str | type[WidgetProtocol] | type[Widget] | None = None,
     options: dict[str, Any] = {},
     record: bool = True,
 ) -> MagicField[Widget, Any]:
+    ...
+
+
+def field(
+    obj=Undefined,
+    *,
+    name=None,
+    label=None,
+    widget_type=None,
+    options={},
+    record=True,
+):
     """
     Make a MagicField object.
 
@@ -637,7 +748,7 @@ def field(
 
     Parameters
     ----------
-    obj : Any, default is UNSET
+    obj : Any, default is Undefined
         Reference to determine what type of widget will be created. If Widget
         subclass is given, it will be used as is. If other type of class is given,
         it will used as type annotation. If an object (not type) is given, it will
@@ -648,7 +759,7 @@ def field(
         Label of the widget.
     widget_type : str, optional
         Widget type. This argument will be sent to ``create_widget`` function.
-    options : WidgetOptions, optional
+    options : dict, optional
         Widget options. This parameter will be passed to the ``options`` keyword
         argument of ``create_widget``.
     record : bool, default is True
@@ -661,6 +772,18 @@ def field(
     return _get_field(obj, name, label, widget_type, options, record, MagicField)
 
 
+@overload
+def vfield(
+    widget_type: type[_W],
+    *,
+    name: str | None = None,
+    label: str | None = None,
+    options: dict[str, Any] = {},
+    record: bool = True,
+) -> MagicValueField[_W, Any]:
+    ...
+
+
 @overload
 def vfield(
     obj: _X,
@@ -674,18 +797,6 @@ def vfield(
     ...
 
 
-@overload
-def vfield(
-    widget_type: type[_W],
-    *,
-    name: str | None = None,
-    label: str | None = None,
-    options: dict[str, Any] = {},
-    record: bool = True,
-) -> MagicValueField[_W, Any]:
-    ...
-
-
 @overload
 def vfield(
     annotation: type[_X],
@@ -725,8 +836,20 @@ def vfield(
     ...
 
 
+@overload
 def vfield(
-    obj: Any = UNSET,
+    *,
+    name: str | None = None,
+    label: str | None = None,
+    widget_type: str | type[WidgetProtocol] | type[Widget] | None = None,
+    options: dict[str, Any] = {},
+    record: bool = True,
+) -> MagicValueField[Widget, Any]:
+    ...
+
+
+def vfield(
+    obj: Any = Undefined,
     *,
     name: str | None = None,
     label: str | None = None,
@@ -747,7 +870,7 @@ def vfield(
 
     Parameters
     ----------
-    obj : Any, default is UNSET
+    obj : Any, default is Undefined
         Reference to determine what type of widget will be created. If Widget
         subclass is given, it will be used as is. If other type of class is given,
         it will used as type annotation. If an object (not type) is given, it will
@@ -758,7 +881,7 @@ def vfield(
         Label of the widget.
     widget_type : str, optional
         Widget type. This argument will be sent to ``create_widget`` function.
-    options : WidgetOptions, optional
+    options : dict, optional
         Widget options. This parameter will be passed to the ``options`` keyword
         argument of ``create_widget``.
     record : bool, default is True
@@ -837,7 +960,7 @@ def _get_field(
             if kwargs["annotation"] is None:
                 kwargs.update(annotation=obj)
             f = field_class(widget_type=widget_type, **kwargs)
-    elif obj is UNSET:
+    elif obj is Undefined:
         f = field_class(widget_type=widget_type, **kwargs)
     else:
         f = field_class(value=obj, widget_type=widget_type, **kwargs)
