@@ -1,7 +1,7 @@
 from __future__ import annotations
 import logging
 from functools import wraps
-from ..widgets import Logger
+from magicclass.widgets import Logger
 
 _LOGGERS: dict[str, Logger] = {}
 
