@@ -24,4 +24,4 @@ from .qt import (
 from ._click import click
 from ._recent import call_recent_menu
 from .qtsignal import QtSignal
-from .qthreading import thread_worker, Timer, Callback
+from .qthreading import thread_worker, Timer, Callback, to_callback
