@@ -23,18 +23,20 @@ from qtpy.QtCore import Qt
 from magicgui.widgets import ProgressBar, Container, Widget, PushButton, Label
 from magicgui.application import use_app
 
-from . import get_signature, move_to_screen_center
+from .qt import move_to_screen_center
 from .qtsignal import QtSignal
+from ._functions import get_signature
 
-from ..widgets.containers import FrameContainer
+from magicclass.widgets.containers import FrameContainer
 
 if TYPE_CHECKING:
-    from .._gui import BaseGui
-    from .._gui.mgui_ext import PushButtonPlus, Action
-    from .._gui._macro import GuiMacro
-    from ..fields import MagicField
+    from magicclass._gui import BaseGui
+    from magicclass._gui.mgui_ext import PushButtonPlus, Action
+    from magicclass._gui._macro import GuiMacro
+    from magicclass.fields import MagicField
+    from typing_extensions import Self
 
-__all__ = ["thread_worker", "Timer", "Callback"]
+__all__ = ["thread_worker", "Timer", "Callback", "to_callback"]
 
 
 class ProgressDict(TypedDict):
@@ -328,7 +330,7 @@ class DefaultProgressBar(FrameContainer, _SupportProgress):
     def show(self):
         parent = self.native.parent()
         self._CONTAINER.append(self)
-        if self._CONTAINER.parent is None:
+        if self._CONTAINER.parent is not parent:
             self._CONTAINER.native.setParent(
                 parent,
                 self._CONTAINER.native.windowFlags(),
@@ -472,7 +474,36 @@ class thread_worker:
         return self._func
 
     @classmethod
-    def set_default(cls, pbar_cls: Callable | str):
+    def with_progress(
+        cls,
+        desc: str | Callable | None = None,
+        total: str | Callable | int = 0,
+        pbar: ProgressBar | _SupportProgress | MagicField | None = None,
+    ) -> Self:
+        """
+        Configure the progressbar.
+
+        Parameters
+        ----------
+        desc : str or callable
+            The description of the progressbar. If a callable is given, it will be
+            called to get the description.
+        total : str, int or callable
+            Total iteration of the progressbar. If a callable is given, it will be
+            called to get the total iteration. If str is given, it will be evaluated
+            with the function's arguments.
+        pbar : ProgressBar or MagicField
+            Progressbar object.
+        """
+        self = cls()
+
+        progress = dict(desc=desc, total=total, pbar=pbar)
+
+        self._progress = progress
+        return self
+
+    @classmethod
+    def set_default(cls, pbar_cls: Callable | str) -> Self:
         """
         Set the default progressbar class.
 
@@ -848,3 +879,6 @@ class Callback:
         if obj is None:
             return self
         return self(obj)
+
+
+to_callback = thread_worker.to_callback
