@@ -1,7 +1,4 @@
-"""
-Advanced widgets for magic class GUI.
-These widgets are all compatible with the ``append`` method of Container widgets.
-"""
+"""magicgui-compatible widgets."""
 
 from magicgui.widgets import *  # to avoid importing both magicgui.widgets and magicclass.widgets
 
@@ -34,7 +31,6 @@ from .misc import (
 )
 from .plot import Figure, SeabornFigure
 from .separator import Separator
-from .sequence import ListEdit, TupleEdit
 from .utils import FreeWidget
 from .logger import Logger
 
@@ -55,7 +51,6 @@ __all__ = [
     "HCollapsibleContainer",
     "HistoryFileEdit",
     "HistoryLineEdit",
-    "ListEdit",
     "ListContainer",
     "ListWidget",
     "Logger",
@@ -70,5 +65,4 @@ __all__ = [
     "StackedContainer",
     "TabbedContainer",
     "ToolBoxContainer",
-    "TupleEdit",
 ]
