@@ -226,6 +226,12 @@ class Figure(FreeWidget):
         self.draw()
         return out
 
+    @_inject_mpl_docs
+    def bar(self, *args, **kwargs) -> None:
+        bars = self.ax.bar(*args, **kwargs)
+        self.draw()
+        return bars
+
     @_inject_mpl_docs
     def text(self, *args, **kwargs) -> Text:
         text = self.ax.text(*args, **kwargs)
@@ -354,6 +360,12 @@ class Figure(FreeWidget):
     def twiny(self) -> Axes:
         return self.ax.twiny()
 
+    @_inject_mpl_docs
+    def grid(self, *args, **kwargs) -> None:
+        self.ax.grid(*args, **kwargs)
+        self.draw()
+        return None
+
     @_inject_mpl_docs
     def box(self, on=None) -> None:
         if on is None:
