@@ -3,11 +3,11 @@ from typing import TYPE_CHECKING
 import weakref
 from qtpy.QtWidgets import QWidget, QVBoxLayout, QGridLayout, QHBoxLayout
 from magicgui.widgets import Widget
-from magicgui.widgets._concrete import merge_super_sigs as _merge_super_sigs
+from magicclass._magicgui_compat import merge_super_sigs as _merge_super_sigs
 from magicgui.backends._qtpy.widgets import QBaseWidget
 
 if TYPE_CHECKING:
-    from .._gui import BaseGui, ContextMenuGui
+    from magicclass._gui import BaseGui, ContextMenuGui
 
 
 class _NotInitialized:
