@@ -1,5 +1,6 @@
 from magicclass import magicclass, magicmenu, magictoolbar
 from magicclass.types import WidgetType
+import pytest
 
 def _make_class(t: WidgetType):
     @magicclass(widget_type=t)
@@ -28,15 +29,14 @@ def _make_class(t: WidgetType):
 
     return A
 
-
-# def test_all_works():
-#     for wtype in WidgetType._member_names_:
-#         ui = _make_class(wtype)()
-#         ui.show(run=False)
-#         ui[0]
-#         ui[1].changed()
-#         ui.B[0].changed()
-#         ui.B[1].changed()
-#         if hasattr(ui, "current_index"):
-#             ui.current_index = 1
-#         ui.close()
+@pytest.mark.parametrize("wtype", WidgetType._member_names_)
+def test_all_works(wtype):
+    ui = _make_class(wtype)()
+    ui.show(run=False)
+    ui[0]
+    ui[1].changed()
+    ui.B[0].changed()
+    ui.B[1].changed()
+    if hasattr(ui, "current_index"):
+        ui.current_index = 1
+    ui.close()
